@@ -25,8 +25,9 @@
 #define E_MAPI_CAL_RECUR_UTILS_H
 
 #include <glib.h>
+#include <libecal/libecal.h>
 
-#include "e-mapi-cal-utils.h"
+#include "e-mapi-connection.h"
 
 G_BEGIN_DECLS
 
@@ -34,7 +35,7 @@ gboolean	e_mapi_cal_util_bin_to_rrule	(const guint8 *lpb,
 						 guint32 cb,
 						 ECalComponent *comp,
 						 GSList **extra_detached,
-						 icaltimezone *recur_zone);
+						 ICalTimezone *recur_zone);
 
 gboolean	e_mapi_cal_util_rrule_to_bin	(ECalComponent *comp,
 						 struct SBinary_short *bin,
